@@ -30,5 +30,5 @@ def index():
              "env": os.getenv('APP_ENV', 'local'),
              "asset": os.getenv('ASSET_ID')}
     else:
-        d = {"status": "Healthy!"}
+        d = {"status": "I am Healthy!"}
     return jsonify(d)
\ No newline at end of file
